"""
googlesearch\n
Make any Google Search right from Python!

© Anime no Sekai — 2021
"""

from googlesearch.googlesearch import Search
from googlesearch import exceptions, models, constants

# For backward compatibility
# old_name = new_name
# if something has been renamed in the new versions

__author__      = 'Anime no Sekai'
__copyright__   = 'Copyright 2021, googlesearch'
__credits__     = ['animenosekai']
__license__     = 'MIT License'
__version__     = 'googlesearch v1.1.0'
__maintainer__  = 'Anime no Sekai'
__email__       = 'niichannomail@gmail.com'
__status__      = 'Stable'